==> mauticGIT-Test-20251212_104643.tar.gz: var/www/html/mauticGIT-Test/var/tmp/twig/d6/d69a1854e4ff204b4bbd82eed66c973f.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/CoreBundle/Assets/js/libraries/froala/languages/es.js */
class __TwigTemplate_f024da4d53ed1a81cc9b8e40cd4a36e9 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "/*!
 * froala_editor v2.4.2 (https://www.froala.com/wysiwyg-editor)
 * License https://froala.com/wysiwyg-editor/terms/
 * Copyright 2014-2017 Froala Labs
 */

/**
 * Spanish
 */

\$.FE.LANGUAGE['es'] = {
  translation: {
    // Place holder
    \"Type something\": \"Escriba algo\",

    // Basic formatting
    \"Bold\": \"Negrita\",
    \"Italic\": \"It\\u00e1lica\",
    \"Underline\": \"Subrayado\",
    \"Strikethrough\": \"Tachado\",

    // Main buttons
    \"Insert\": \"Insertar\",
    \"Delete\": \"Borrar\",
    \"Cancel\": \"Cancelar\",
    \"OK\": \"Ok\",
    \"Back\": \"Atr\\u00e1s\",
    \"Remove\": \"Quitar\",
    \"More\": \"M\\u00e1s\",
    \"Update\": \"Actualizaci\\u00f3n\",
    \"Style\": \"\",

    // Font
    \"Font Family\": \"Familia de fuentes\",
    \"Font Size\": \"Tama\\u00f1o de fuente\",

    // Colors
    \"Colors\": \"Colores\",
    \"Background\": \"Fondo\",
    \"Text\": \"Texto\",

    // Paragraphs
    \"Paragraph Format\": \"Formato de p\\u00e1rrafo\",
    \"Normal\": \"Normal\",
    \"Code\": \"C\\u00f3digo\",
    \"Heading 1\": \"Encabezado 1\",
    \"Heading 2\": \"Encabezado 2\",
    \"Heading 3\": \"Encabezado 3\",
    \"Heading 4\": \"Encabezado 4\",

    // Style
    \"Paragraph Style\": \"Estilo de p\\u00e1rrafo\",
    \"Inline Style\": \"Estilo en l\\u00ednea\",

    // Alignment
    \"Align\": \"Alinear\",
    \"Align Left\": \"Alinear a la izquierda\",
    \"Align Center\": \"Alinear al centro\",
    \"Align Right\": \"Alinear a la derecha\",
    \"Align Justify\": \"Justificar\",
    \"None\": \"Ninguno\",

    // Lists
    \"Ordered List\": \"Lista ordenada\",
    \"Unordered List\": \"Lista desordenada\",

    // Indent
    \"Decrease Indent\": \"Reducir sangr\\u00eda\",
    \"Increase Indent\": \"Aumentar sangr\\u00eda\",

    // Links
    \"Insert Link\": \"Insertar enlace\",
    \"Open in new tab\": \"Abrir en una nueva pesta\\u00F1a\",
    \"Open Link\": \"Abrir enlace\",
    \"Edit Link\": \"Editar enlace\",
    \"Unlink\": \"Quitar enlace\",
    \"Choose Link\": \"Elegir enlace\",

    // Images
    \"Insert Image\": \"Insertar imagen\",
    \"Upload Image\": \"Cargar imagen\",
    \"By URL\": \"Por URL\",
    \"Browse\": \"Examinar\",
    \"Drop image\": \"Soltar la imagen\",
    \"or click\": \"o haga clic en\",
    \"Manage Images\": \"Administrar im\\u00e1genes\",
    \"Loading\": \"Cargando\",
    \"Deleting\": \"Borrado\",
    \"Tags\": \"Etiquetas\",
    \"Are you sure? Image will be deleted.\": \"\\u00bfEst\\u00e1 seguro? Imagen ser\\u00e1 borrada.\",
    \"Replace\": \"Reemplazar\",
    \"Uploading\": \"Carga\",
    \"Loading image\": \"Cargando imagen\",
    \"Display\": \"Mostrar\",
    \"Inline\": \"En l\\u00ednea\",
    \"Break Text\": \"Romper texto\",
    \"Alternate Text\": \"Texto alternativo\",
    \"Change Size\": \"Cambiar tama\\u00f1o\",
    \"Width\": \"Ancho\",
    \"Height\": \"Altura\",
    \"Something went wrong. Please try again.\": \"Algo sali\\u00f3 mal. Por favor, vuelva a intentarlo.\",

    // Video
    \"Insert Video\": \"Insertar video\",
    \"Embedded Code\": \"C\\u00f3digo incrustado\",

    // Tables
    \"Insert Table\": \"Insertar tabla\",
    \"Table Header\": \"Encabezado de la tabla\",
    \"Remove Table\": \"Retire la tabla\",
    \"Table Style\": \"Estilo de tabla\",
    \"Horizontal Align\": \"Alinear horizontal\",
    \"Row\": \"Fila\",
    \"Insert row above\": \"Insertar fila antes\",
    \"Insert row below\": \"Insertar fila despu\\u00e9s\",
    \"Delete row\": \"Eliminar fila\",
    \"Column\": \"Columna\",
    \"Insert column before\": \"Insertar columna antes\",
    \"Insert column after\": \"Insertar columna despu\\u00e9s\",
    \"Delete column\": \"Eliminar columna\",
    \"Cell\": \"Celda\",
    \"Merge cells\": \"Combinar celdas\",
    \"Horizontal split\": \"Divisi\\u00f3n horizontal\",
    \"Vertical split\": \"Divisi\\u00f3n vertical\",
    \"Cell Background\": \"Fondo de la celda\",
    \"Vertical Align\": \"Alinear vertical\",
    \"Top\": \"Cima\",
    \"Middle\": \"Medio\",
    \"Bottom\": \"Del fondo\",
    \"Align Top\": \"Alinear a la parte superior\",
    \"Align Middle\": \"Alinear media\",
    \"Align Bottom\": \"Alinear abajo\",
    \"Cell Style\": \"Estilo de celda\",

    // Files
    \"Upload File\": \"Subir archivo\",
    \"Drop file\": \"Soltar archivo\",

    // Emoticons
    \"Emoticons\": \"Emoticones\",
    \"Grinning face\": \"Sonriendo cara\",
    \"Grinning face with smiling eyes\": \"Sonriendo cara con ojos sonrientes\",
    \"Face with tears of joy\": \"Cara con l\\u00e1grimas de alegr\\u00eda\",
    \"Smiling face with open mouth\": \"Cara sonriente con la boca abierta\",
    \"Smiling face with open mouth and smiling eyes\": \"Cara sonriente con la boca abierta y los ojos sonrientes\",
    \"Smiling face with open mouth and cold sweat\": \"Cara sonriente con la boca abierta y el sudor fr\\u00edo\",
    \"Smiling face with open mouth and tightly-closed eyes\": \"Cara sonriente con la boca abierta y los ojos fuertemente cerrados\",
    \"Smiling face with halo\": \"Cara sonriente con halo\",
    \"Smiling face with horns\": \"Cara sonriente con cuernos\",
    \"Winking face\": \"Gui\\u00f1o de la cara\",
    \"Smiling face with smiling eyes\": \"Cara sonriente con ojos sonrientes\",
    \"Face savoring delicious food\": \"Care saborear una deliciosa comida\",
    \"Relieved face\": \"Cara Aliviado\",
    \"Smiling face with heart-shaped eyes\": \"Cara sonriente con los ojos en forma de coraz\\u00f3n\",
    \"Smiling face with sunglasses\": \"Cara sonriente con gafas de sol\",
    \"Smirking face\": \"Sonriendo cara\",
    \"Neutral face\": \"Cara neutral\",
    \"Expressionless face\": \"Rostro inexpresivo\",
    \"Unamused face\": \"Cara no divertido\",
    \"Face with cold sweat\": \"Cara con sudor fr\\u00edo\",
    \"Pensive face\": \"Rostro pensativo\",
    \"Confused face\": \"Cara confusa\",
    \"Confounded face\": \"Cara Averg\\u00fc\\u00e9ncense\",
    \"Kissing face\": \"Besar la cara\",
    \"Face throwing a kiss\": \"Cara lanzando un beso\",
    \"Kissing face with smiling eyes\": \"Besar a cara con ojos sonrientes\",
    \"Kissing face with closed eyes\": \"Besar a cara con los ojos cerrados\",
    \"Face with stuck out tongue\": \"Cara con la lengua pegada\",
    \"Face with stuck out tongue and winking eye\": \"Cara con pegado a la lengua y los ojos gui\\u00f1o\",
    \"Face with stuck out tongue and tightly-closed eyes\": \"Cara con la lengua pegada a y los ojos fuertemente cerrados\",
    \"Disappointed face\": \"Cara decepcionado\",
    \"Worried face\": \"Cara de preocupaci\\u00f3n\",
    \"Angry face\": \"Cara enojada\",
    \"Pouting face\": \"Que pone mala cara\",
    \"Crying face\": \"Cara llorando\",
    \"Persevering face\": \"Perseverar cara\",
    \"Face with look of triumph\": \"Cara con expresi\\u00f3n de triunfo\",
    \"Disappointed but relieved face\": \"Decepcionado pero el rostro aliviado\",
    \"Frowning face with open mouth\": \"Con el ce\\u00f1o fruncido la cara con la boca abierta\",
    \"Anguished face\": \"Rostro angustiado\",
    \"Fearful face\": \"Cara Temeroso\",
    \"Weary face\": \"Rostro cansado\",
    \"Sleepy face\": \"Rostro so\\u00f1oliento\",
    \"Tired face\": \"Rostro cansado\",
    \"Grimacing face\": \"Haciendo una mueca cara\",
    \"Loudly crying face\": \"Llorando en voz alta la cara\",
    \"Face with open mouth\": \"Cara con la boca abierta\",
    \"Hushed face\": \"Cara callada\",
    \"Face with open mouth and cold sweat\": \"Cara con la boca abierta y el sudor frío\",
    \"Face screaming in fear\": \"Cara gritando de miedo\",
    \"Astonished face\": \"Cara asombrosa\",
    \"Flushed face\": \"Cara enrojecida\",
    \"Sleeping face\": \"Rostro dormido\",
    \"Dizzy face\": \"Cara Mareado\",
    \"Face without mouth\": \"Cara sin boca\",
    \"Face with medical mask\": \"Cara con la m\\u00e1scara m\\u00e9dica\",

    // Line breaker
    \"Break\": \"Romper\",

    // Math
    \"Subscript\": \"Sub\\u00edndice\",
    \"Superscript\": \"Super\\u00edndice\",

    // Full screen
    \"Fullscreen\": \"Pantalla completa\",

    // Horizontal line
    \"Insert Horizontal Line\": \"Insertar l\\u00ednea horizontal\",

    // Clear formatting
    \"Clear Formatting\": \"Quitar el formato\",

    // Undo, redo
    \"Undo\": \"Deshacer\",
    \"Redo\": \"Rehacer\",

    // Select all
    \"Select All\": \"Seleccionar todo\",

    // Code view
    \"Code View\": \"Vista de c\\u00f3digo\",

    // Quote
    \"Quote\": \"Cita\",
    \"Increase\": \"Aumentar\",
    \"Decrease\": \"Disminuci\\u00f3n\",

    // Quick Insert
    \"Quick Insert\": \"Inserci\\u00f3n r\\u00e1pida\"
  },
  direction: \"ltr\"
};
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/CoreBundle/Assets/js/libraries/froala/languages/es.js";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/CoreBundle/Assets/js/libraries/froala/languages/es.js", "/var/www/mautic-ktn/app/bundles/CoreBundle/Assets/js/libraries/froala/languages/es.js");
    }
}

==> mauticGIT-Test-20260116_092227.tar.gz: var/www/html/mauticGIT-Test/var/tmp/twig/d6/d69a1854e4ff204b4bbd82eed66c973f.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/CoreBundle/Assets/js/libraries/froala/languages/es.js */
class __TwigTemplate_f024da4d53ed1a81cc9b8e40cd4a36e9 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "/*!
 * froala_editor v2.4.2 (https://www.froala.com/wysiwyg-editor)
 * License https://froala.com/wysiwyg-editor/terms/
 * Copyright 2014-2017 Froala Labs
 */

/**
 * Spanish
 */

\$.FE.LANGUAGE['es'] = {
  translation: {
    // Place holder
    \"Type something\": \"Escriba algo\",

    // Basic formatting
    \"Bold\": \"Negrita\",
    \"Italic\": \"It\\u00e1lica\",
    \"Underline\": \"Subrayado\",
    \"Strikethrough\": \"Tachado\",

    // Main buttons
    \"Insert\": \"Insertar\",
    \"Delete\": \"Borrar\",
    \"Cancel\": \"Cancelar\",
    \"OK\": \"Ok\",
    \"Back\": \"Atr\\u00e1s\",
    \"Remove\": \"Quitar\",
    \"More\": \"M\\u00e1s\",
    \"Update\": \"Actualizaci\\u00f3n\",
    \"Style\": \"\",

    // Font
    \"Font Family\": \"Familia de fuentes\",
    \"Font Size\": \"Tama\\u00f1o de fuente\",

    // Colors
    \"Colors\": \"Colores\",
    \"Background\": \"Fondo\",
    \"Text\": \"Texto\",

    // Paragraphs
    \"Paragraph Format\": \"Formato de p\\u00e1rrafo\",
    \"Normal\": \"Normal\",
    \"Code\": \"C\\u00f3digo\",
    \"Heading 1\": \"Encabezado 1\",
    \"Heading 2\": \"Encabezado 2\",
    \"Heading 3\": \"Encabezado 3\",
    \"Heading 4\": \"Encabezado 4\",

    // Style
    \"Paragraph Style\": \"Estilo de p\\u00e1rrafo\",
    \"Inline Style\": \"Estilo en l\\u00ednea\",

    // Alignment
    \"Align\": \"Alinear\",
    \"Align Left\": \"Alinear a la izquierda\",
    \"Align Center\": \"Alinear al centro\",
    \"Align Right\": \"Alinear a la derecha\",
    \"Align Justify\": \"Justificar\",
    \"None\": \"Ninguno\",

    // Lists
    \"Ordered List\": \"Lista ordenada\",
    \"Unordered List\": \"Lista desordenada\",

    // Indent
    \"Decrease Indent\": \"Reducir sangr\\u00eda\",
    \"Increase Indent\": \"Aumentar sangr\\u00eda\",

    // Links
    \"Insert Link\": \"Insertar enlace\",
    \"Open in new tab\": \"Abrir en una nueva pesta\\u00F1a\",
    \"Open Link\": \"Abrir enlace\",
    \"Edit Link\": \"Editar enlace\",
    \"Unlink\": \"Quitar enlace\",
    \"Choose Link\": \"Elegir enlace\",

    // Images
    \"Insert Image\": \"Insertar imagen\",
    \"Upload Image\": \"Cargar imagen\",
    \"By URL\": \"Por URL\",
    \"Browse\": \"Examinar\",
    \"Drop image\": \"Soltar la imagen\",
    \"or click\": \"o haga clic en\",
    \"Manage Images\": \"Administrar im\\u00e1genes\",
    \"Loading\": \"Cargando\",
    \"Deleting\": \"Borrado\",
    \"Tags\": \"Etiquetas\",
    \"Are you sure? Image will be deleted.\": \"\\u00bfEst\\u00e1 seguro? Imagen ser\\u00e1 borrada.\",
    \"Replace\": \"Reemplazar\",
    \"Uploading\": \"Carga\",
    \"Loading image\": \"Cargando imagen\",
    \"Display\": \"Mostrar\",
    \"Inline\": \"En l\\u00ednea\",
    \"Break Text\": \"Romper texto\",
    \"Alternate Text\": \"Texto alternativo\",
    \"Change Size\": \"Cambiar tama\\u00f1o\",
    \"Width\": \"Ancho\",
    \"Height\": \"Altura\",
    \"Something went wrong. Please try again.\": \"Algo sali\\u00f3 mal. Por favor, vuelva a intentarlo.\",

    // Video
    \"Insert Video\": \"Insertar video\",
    \"Embedded Code\": \"C\\u00f3digo incrustado\",

    // Tables
    \"Insert Table\": \"Insertar tabla\",
    \"Table Header\": \"Encabezado de la tabla\",
    \"Remove Table\": \"Retire la tabla\",
    \"Table Style\": \"Estilo de tabla\",
    \"Horizontal Align\": \"Alinear horizontal\",
    \"Row\": \"Fila\",
    \"Insert row above\": \"Insertar fila antes\",
    \"Insert row below\": \"Insertar fila despu\\u00e9s\",
    \"Delete row\": \"Eliminar fila\",
    \"Column\": \"Columna\",
    \"Insert column before\": \"Insertar columna antes\",
    \"Insert column after\": \"Insertar columna despu\\u00e9s\",
    \"Delete column\": \"Eliminar columna\",
    \"Cell\": \"Celda\",
    \"Merge cells\": \"Combinar celdas\",
    \"Horizontal split\": \"Divisi\\u00f3n horizontal\",
    \"Vertical split\": \"Divisi\\u00f3n vertical\",
    \"Cell Background\": \"Fondo de la celda\",
    \"Vertical Align\": \"Alinear vertical\",
    \"Top\": \"Cima\",
    \"Middle\": \"Medio\",
    \"Bottom\": \"Del fondo\",
    \"Align Top\": \"Alinear a la parte superior\",
    \"Align Middle\": \"Alinear media\",
    \"Align Bottom\": \"Alinear abajo\",
    \"Cell Style\": \"Estilo de celda\",

    // Files
    \"Upload File\": \"Subir archivo\",
    \"Drop file\": \"Soltar archivo\",

    // Emoticons
    \"Emoticons\": \"Emoticones\",
    \"Grinning face\": \"Sonriendo cara\",
    \"Grinning face with smiling eyes\": \"Sonriendo cara con ojos sonrientes\",
    \"Face with tears of joy\": \"Cara con l\\u00e1grimas de alegr\\u00eda\",
    \"Smiling face with open mouth\": \"Cara sonriente con la boca abierta\",
    \"Smiling face with open mouth and smiling eyes\": \"Cara sonriente con la boca abierta y los ojos sonrientes\",
    \"Smiling face with open mouth and cold sweat\": \"Cara sonriente con la boca abierta y el sudor fr\\u00edo\",
    \"Smiling face with open mouth and tightly-closed eyes\": \"Cara sonriente con la boca abierta y los ojos fuertemente cerrados\",
    \"Smiling face with halo\": \"Cara sonriente con halo\",
    \"Smiling face with horns\": \"Cara sonriente con cuernos\",
    \"Winking face\": \"Gui\\u00f1o de la cara\",
    \"Smiling face with smiling eyes\": \"Cara sonriente con ojos sonrientes\",
    \"Face savoring delicious food\": \"Care saborear una deliciosa comida\",
    \"Relieved face\": \"Cara Aliviado\",
    \"Smiling face with heart-shaped eyes\": \"Cara sonriente con los ojos en forma de coraz\\u00f3n\",
    \"Smiling face with sunglasses\": \"Cara sonriente con gafas de sol\",
    \"Smirking face\": \"Sonriendo cara\",
    \"Neutral face\": \"Cara neutral\",
    \"Expressionless face\": \"Rostro inexpresivo\",
    \"Unamused face\": \"Cara no divertido\",
    \"Face with cold sweat\": \"Cara con sudor fr\\u00edo\",
    \"Pensive face\": \"Rostro pensativo\",
    \"Confused face\": \"Cara confusa\",
    \"Confounded face\": \"Cara Averg\\u00fc\\u00e9ncense\",
    \"Kissing face\": \"Besar la cara\",
    \"Face throwing a kiss\": \"Cara lanzando un beso\",
    \"Kissing face with smiling eyes\": \"Besar a cara con ojos sonrientes\",
    \"Kissing face with closed eyes\": \"Besar a cara con los ojos cerrados\",
    \"Face with stuck out tongue\": \"Cara con la lengua pegada\",
    \"Face with stuck out tongue and winking eye\": \"Cara con pegado a la lengua y los ojos gui\\u00f1o\",
    \"Face with stuck out tongue and tightly-closed eyes\": \"Cara con la lengua pegada a y los ojos fuertemente cerrados\",
    \"Disappointed face\": \"Cara decepcionado\",
    \"Worried face\": \"Cara de preocupaci\\u00f3n\",
    \"Angry face\": \"Cara enojada\",
    \"Pouting face\": \"Que pone mala cara\",
    \"Crying face\": \"Cara llorando\",
    \"Persevering face\": \"Perseverar cara\",
    \"Face with look of triumph\": \"Cara con expresi\\u00f3n de triunfo\",
    \"Disappointed but relieved face\": \"Decepcionado pero el rostro aliviado\",
    \"Frowning face with open mouth\": \"Con el ce\\u00f1o fruncido la cara con la boca abierta\",
    \"Anguished face\": \"Rostro angustiado\",
    \"Fearful face\": \"Cara Temeroso\",
    \"Weary face\": \"Rostro cansado\",
    \"Sleepy face\": \"Rostro so\\u00f1oliento\",
    \"Tired face\": \"Rostro cansado\",
    \"Grimacing face\": \"Haciendo una mueca cara\",
    \"Loudly crying face\": \"Llorando en voz alta la cara\",
    \"Face with open mouth\": \"Cara con la boca abierta\",
    \"Hushed face\": \"Cara callada\",
    \"Face with open mouth and cold sweat\": \"Cara con la boca abierta y el sudor frío\",
    \"Face screaming in fear\": \"Cara gritando de miedo\",
    \"Astonished face\": \"Cara asombrosa\",
    \"Flushed face\": \"Cara enrojecida\",
    \"Sleeping face\": \"Rostro dormido\",
    \"Dizzy face\": \"Cara Mareado\",
    \"Face without mouth\": \"Cara sin boca\",
    \"Face with medical mask\": \"Cara con la m\\u00e1scara m\\u00e9dica\",

    // Line breaker
    \"Break\": \"Romper\",

    // Math
    \"Subscript\": \"Sub\\u00edndice\",
    \"Superscript\": \"Super\\u00edndice\",

    // Full screen
    \"Fullscreen\": \"Pantalla completa\",

    // Horizontal line
    \"Insert Horizontal Line\": \"Insertar l\\u00ednea horizontal\",

    // Clear formatting
    \"Clear Formatting\": \"Quitar el formato\",

    // Undo, redo
    \"Undo\": \"Deshacer\",
    \"Redo\": \"Rehacer\",

    // Select all
    \"Select All\": \"Seleccionar todo\",

    // Code view
    \"Code View\": \"Vista de c\\u00f3digo\",

    // Quote
    \"Quote\": \"Cita\",
    \"Increase\": \"Aumentar\",
    \"Decrease\": \"Disminuci\\u00f3n\",

    // Quick Insert
    \"Quick Insert\": \"Inserci\\u00f3n r\\u00e1pida\"
  },
  direction: \"ltr\"
};
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/CoreBundle/Assets/js/libraries/froala/languages/es.js";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/CoreBundle/Assets/js/libraries/froala/languages/es.js", "/var/www/html/mauticGIT-Test/app/bundles/CoreBundle/Assets/js/libraries/froala/languages/es.js");
    }
}
